# Reproducible trainings with Ignite

Inspired by [torchvision/references](https://github.com/pytorch/vision/tree/master/references), we provide several
reproducible baselines for vision tasks:

- [x] Classification

  - [x] [ImageNet](classification/imagenet)

- [x] Segmentation
  - [x] [Pascal VOC2012](segmentation/pascal_voc2012)
